@@ -1,3 +1,5 @@
+import weakref
+
 __events = {}
 __disabled_events = set([])
 
@@ -6,10 +8,16 @@ def noop(*args, **kwargs):
     pass
 
 
-class Callables(list):
+class WeakList(list):
+    def append(self, item):
+        list.append(self, weakref.WeakMethod(item, self.remove))
+
+
+class Callables(WeakList):
     def __call__(self, *args, **kwargs):
-        for f in self:
-            f(*args, **kwargs)
+        for func in self:
+            # weakref: needs to be de-ref'd first before calling
+            func()(*args, **kwargs)
 
     def __repr__(self):
         return "Callables(%s)" % list.__repr__(self)
