@@ -99,7 +99,7 @@ def _paramset_requirements_from_modelspec(spec, channel_nbins):
 
 def _nominal_and_modifiers_from_spec(config, spec):
     default_data_makers = {
-        'histosys': lambda: {'hi_data': [], 'lo_data': [], 'nom_data': [], 'mask': [],},
+        'histosys': lambda: {'hi_data': [], 'lo_data': [], 'nom_data': [], 'mask': []},
         'lumi': lambda: {'mask': []},
         'normsys': lambda: {'hi': [], 'lo': [], 'nom_data': [], 'mask': []},
         'normfactor': lambda: {'mask': []},
@@ -453,7 +453,7 @@ class _MainModel(object):
         return True
 
     def make_pdf(self, pars):
-        lambdas_data = self._expected_data(pars)
+        lambdas_data = self.expected_data(pars)
         return prob.Independent(prob.Poisson(lambdas_data))
 
     def logpdf(self, maindata, pars):
@@ -486,7 +486,7 @@ class _MainModel(object):
 
         return deltas, factors
 
-    def _expected_data(self, pars):
+    def expected_data(self, pars, return_by_sample=False):
         """
         Compute the expected rates for given values of parameters.
 
@@ -514,6 +514,7 @@ class _MainModel(object):
 
         """
         tensorlib, _ = get_backend()
+        pars = tensorlib.astensor(pars)
         deltas, factors = self._modifications(pars)
 
         allsum = tensorlib.concatenate(deltas + [self.nominal_rates])
@@ -526,6 +527,12 @@ class _MainModel(object):
         allfac = tensorlib.concatenate(factors + [nom_plus_delta])
 
         newbysample = tensorlib.product(allfac, axis=0)
+        if return_by_sample:
+            batch_first = tensorlib.einsum('ij...->ji...', newbysample)
+            if self.batch_size is None:
+                return batch_first[0]
+            return batch_first
+
         newresults = tensorlib.sum(newbysample, axis=0)
         if self.batch_size is None:
             return newresults[0]
@@ -603,6 +610,8 @@ class Model(object):
             Tensor: The expected data of the auxiliary pdf
 
         """
+        tensorlib, _ = get_backend()
+        pars = tensorlib.astensor(pars)
         return self.make_pdf(pars)[1].expected_data()
 
     def _modifications(self, pars):
@@ -624,6 +633,8 @@ class Model(object):
             Tensor: The expected data of the main model (no auxiliary data)
 
         """
+        tensorlib, _ = get_backend()
+        pars = tensorlib.astensor(pars)
         return self.make_pdf(pars)[0].expected_data()
 
     def expected_data(self, pars, include_auxdata=True):
