@@ -473,6 +473,9 @@ class Workspace(_ChannelSummaryMixin, dict):
         Returns:
             ~pyhf.workspace.Workspace: A new workspace object with the specified components removed or renamed
 
+        Raises:
+          ~pyhf.exceptions.InvalidWorkspaceOperation: An item name to prune or rename does not exist in the workspace.
+
         """
         # avoid mutable defaults
         prune_modifiers = [] if prune_modifiers is None else prune_modifiers
@@ -487,6 +490,36 @@ class Workspace(_ChannelSummaryMixin, dict):
         rename_channels = {} if rename_channels is None else rename_channels
         rename_measurements = {} if rename_measurements is None else rename_measurements
 
+        for modifier_type in prune_modifier_types:
+            if modifier_type not in dict(self.modifiers).values():
+                raise exceptions.InvalidWorkspaceOperation(
+                    f"{modifier_type} is not one of the modifier types in this workspace."
+                )
+
+        for modifier_name in (*prune_modifiers, *rename_modifiers.keys()):
+            if modifier_name not in dict(self.modifiers):
+                raise exceptions.InvalidWorkspaceOperation(
+                    f"{modifier_name} is not one of the modifiers in this workspace."
+                )
+
+        for sample_name in (*prune_samples, *rename_samples.keys()):
+            if sample_name not in self.samples:
+                raise exceptions.InvalidWorkspaceOperation(
+                    f"{sample_name} is not one of the samples in this workspace."
+                )
+
+        for channel_name in (*prune_channels, *rename_channels.keys()):
+            if channel_name not in self.channels:
+                raise exceptions.InvalidWorkspaceOperation(
+                    f"{channel_name} is not one of the channels in this workspace."
+                )
+
+        for measurement_name in (*prune_measurements, *rename_measurements.keys()):
+            if measurement_name not in self.measurement_names:
+                raise exceptions.InvalidWorkspaceOperation(
+                    f"{measurement_name} is not one of the measurements in this workspace."
+                )
+
         newspec = {
             'channels': [
                 {
@@ -573,6 +606,9 @@ class Workspace(_ChannelSummaryMixin, dict):
         Returns:
             ~pyhf.workspace.Workspace: A new workspace object with the specified components removed
 
+        Raises:
+          ~pyhf.exceptions.InvalidWorkspaceOperation: An item name to prune does not exist in the workspace.
+
         """
         # avoid mutable defaults
         modifiers = [] if modifiers is None else modifiers
@@ -605,6 +641,9 @@ class Workspace(_ChannelSummaryMixin, dict):
         Returns:
             ~pyhf.workspace.Workspace: A new workspace object with the specified components renamed
 
+        Raises:
+          ~pyhf.exceptions.InvalidWorkspaceOperation: An item name to rename does not exist in the workspace.
+
         """
         # avoid mutable defaults
         modifiers = {} if modifiers is None else modifiers
@@ -675,4 +714,32 @@ class Workspace(_ChannelSummaryMixin, dict):
             'observations': new_observations,
             'version': new_version,
         }
-        return Workspace(newspec)
+        return cls(newspec)
+
+    @classmethod
+    def sorted(cls, workspace):
+        """
+        Return a new workspace specification that is sorted.
+
+        Args:
+            workspace (~pyhf.workspace.Workspace): A workspace to sort
+
+        Returns:
+            ~pyhf.workspace.Workspace: A new sorted workspace object
+
+        """
+        newspec = copy.deepcopy(dict(workspace))
+
+        newspec['channels'].sort(key=lambda e: e['name'])
+        for channel in newspec['channels']:
+            channel['samples'].sort(key=lambda e: e['name'])
+            for sample in channel['samples']:
+                sample['modifiers'].sort(key=lambda e: (e['name'], e['type']))
+
+        newspec['measurements'].sort(key=lambda e: e['name'])
+        for measurement in newspec['measurements']:
+            measurement['config']['parameters'].sort(key=lambda e: e['name'])
+
+        newspec['observations'].sort(key=lambda e: e['name'])
+
+        return cls(newspec)
